@@ -16,9 +16,9 @@ class WorkerResult():
 
 
 class Worker(Process):
-    haar_files = os.path.join(Path(__file__).parent.parent, "haar cascade files")
-    LeftEye = cv2.CascadeClassifier(os.path.join(haar_files, 'haarcascade_lefteye_2splits.xml'))
-    RightEye = cv2.CascadeClassifier(os.path.join(haar_files, 'haarcascade_righteye_2splits.xml'))
+    __haar_files = os.path.join(Path(__file__).parent.parent, "haar cascade files")
+    __LeftEye = cv2.CascadeClassifier(os.path.join(__haar_files, 'haarcascade_lefteye_2splits.xml'))
+    __RightEye = cv2.CascadeClassifier(os.path.join(__haar_files, 'haarcascade_righteye_2splits.xml'))
 
     def __init__(self,input_frames,result_queue):
         super().__init__()
@@ -26,7 +26,7 @@ class Worker(Process):
         self.result_queue = result_queue
         self.model = None
 
-    def predict(self,Eye):
+    def __predict(self,Eye):
         if self.model is None:
             from keras.models import load_model
             self.model = load_model(os.path.join(Path(__file__).parent, 'cnnCat4.h5'))
@@ -44,11 +44,11 @@ class Worker(Process):
         while True:
             if not self.input_queue.empty():
                 frame = self.input_queue.get()
-                worker_result = self.process(frame)
+                worker_result = self.__process(frame)
                 print(worker_result)
                 self.result_queue.put(worker_result)
 
-    def adjust_gamma(self,image, gamma=1.0):
+    def __adjust_gamma(self,image, gamma=1.0):
 
         invGamma = 1.0 / gamma
         table = np.array([((i / 255.0) ** invGamma) * 255
@@ -56,12 +56,12 @@ class Worker(Process):
 
         return cv2.LUT(image, table)
 
-    def process(self,frame):
+    def __process(self,frame):
         gray = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
         gray = cv2.equalizeHist(gray)
-        gray = self.adjust_gamma(gray,gamma=1.5)
-        left_eyes = self.__class__.LeftEye.detectMultiScale(gray)
-        right_eyes = self.__class__.RightEye.detectMultiScale(gray)
+        gray = self.__adjust_gamma(gray,gamma=1.5)
+        left_eyes = self.__class__.__LeftEye.detectMultiScale(gray)
+        right_eyes = self.__class__.__RightEye.detectMultiScale(gray)
 
         result = WorkerResult(leftEye=None,RightEye=None,openProbability=None)
 
@@ -75,12 +75,12 @@ class Worker(Process):
             left_eyes = gray[y:y + h, x:x + w]
             break
 
-        l = self.process_single_eye(right_eyes)
-        r = self.process_single_eye(left_eyes)
-        result.OpenProbability = self.predict(l) or self.predict(r)
+        l = self.__process_single_eye(right_eyes)
+        r = self.__process_single_eye(left_eyes)
+        result.OpenProbability = self.__predict(l) or self.__predict(r)
         return result
 
-    def process_single_eye(self,eye):
+    def __process_single_eye(self,eye):
         try:
             eye = cv2.resize(eye, (24, 24))
             # having values of every element between 0 and 1
